@@ -14,8 +14,10 @@ overview_plot_absolute <-
            yaxis = NULL,
            xaxis = NULL) {
     plot <- ggplot2::ggplot(data = dat_result) +
-      ggplot2::geom_col(ggplot2::aes(y = reorder(variable, -na_count),
-                                     x = na_count)) +
+      ggplot2::geom_col(ggplot2::aes(
+        y = reorder(variable, -na_count),
+        x = na_count
+      )) +
       ggplot2::ylab(yaxis) +
       ggplot2::xlab(xaxis) +
       theme_plot
